powered by
The digits of the old version (before 2000 year) of 'Chinese ID Card Number' is 15, this package aims to update to the current version of 18 digits.
id.15to18(id.15)
vector of numeric or character, the old version of Chinese ID Card Number
character, the new version of Chinese ID Card Number
# NOT RUN { id.15to18(id.15="441900890101221") id.15to18(id.15=rep("441900890101221",2)) # }
Run the code above in your browser using DataLab