Learn R Programming

IDCard (version 0.3.0)

id.15to18.single: Update Chinese ID Card Number to Eighteen Digits

Description

The digits of the old version (before 2000 year) of 'Chinese ID Card Number' is 15, this package aims to update to the current version of 18 digits.

Usage

id.15to18.single(id.15)

Arguments

id.15

numeric or character, the old version of Chinese ID Card Number

Value

id.18

character, the new version of Chinese ID Card Number

Examples

Run this code
# NOT RUN {
id.15to18.single(id.15="441900890101221")
# }

Run the code above in your browser using DataLab